# SUI
SUI(Some Useful Implementations) is a package including selected implementations apropos machine learning, deep learning, and other useful classes or functions.

## 0. Why SUI?
SUI is a framework integrated a spate of sound and applicable models apropos machine learning and deep learning based on top-notch publications and dependable open-source frameworks. In SUI, there are models being ubiquitous in industrial projects. For all some of these algorithms might be obsolete, they are still not feckless. Every model can be a felicitous solution for a meet scenario.

## 1. Install
Use pip to install SUI is highly recommended. Open your terminal and input:
```bash
pip install sui
```
Then, open python to import SUI and test it by:
```python
import sui

print(sui.my_dear)
```

## 2. Get Started
To get information of any API in SUI, you can call the function 'sui.api_info' with no specified 'api' to demonstrate every API and its information, or you can specify an API as 'sui.api_info(api='sui.LIN')'.
```python
# get information of all APIs
sui.api_info()

# get information of 'sui.LIN'
sui.api_info('sui.LIN')
```